@@ -99,7 +99,12 @@ def deploy(type, port):
             "a100":"aitemplate",
             "t4":"tensorrt"
         }
-        gpu_info = get_gpu_info()[0]
+        
+        gpu_info = None
+        try:
+            gpu_info = get_gpu_info()[0]
+        except:
+            pass
         
         # If there is no GPU
         if gpu_info is None or len(gpu_info) == 0:
